## 同花顺概念板块成分

接口：ths_member

描述：获取同花顺概念板块成分列表注：数据版权归属同花顺，如做商业用途，请主动联系同花顺。

限量：用户积累5000积分可调取，每分钟可调取200次，可按概念板块代码循环提取所有成分

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 板块指数代码 |
| con_code | str | N | 股票代码 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 指数代码 |
| con_code | str | Y | 股票代码 |
| con_name | str | Y | 股票名称 |
| weight | float | N | 权重(暂无) |
| in_date | str | N | 纳入日期(暂无) |
| out_date | str | N | 剔除日期(暂无) |
| is_new | str | N | 是否最新Y是N否 |

接口示例

```python
pro = ts.pro_api()

df = pro.ths_member(ts_code='885800.TI')
```

数据样例

```python
ts_code         con_code     con_name
0   885800.TI  000016.SZ  深康佳A
```